from uuid import uuid4

from bsubio.api_client import ApiClient


class _DummyPool:
    def __init__(self) -> None:
        self.cleared = False

    def clear(self) -> None:
        self.cleared = True


class _DummyRestClient:
    def __init__(self) -> None:
        self.pool_manager = _DummyPool()


def test_api_client_context_clears_pool() -> None:
    client = ApiClient()
    client.rest_client = _DummyRestClient()

    with client:
        pass

    assert client.rest_client.pool_manager.cleared is True


def test_sanitize_for_serialization_handles_uuid() -> None:
    client = ApiClient()
    uid = uuid4()

    assert client.sanitize_for_serialization(uid) == str(uid)



import json
import os
import time
from pathlib import Path
from uuid import uuid4

import pytest

from bsubio import (
    ApiClient,
    ApiException,
    Configuration,
    CreateJobRequest,
    JobsApi,
    OutputApi,
    SystemApi,
)


def _require_live_config() -> Configuration:
    api_key = os.getenv("BSUB_API_KEY")
    base_url = os.getenv("BSUB_BASE_URL")

    if not api_key and os.getenv("BSUB_TEST_USE_CONFIG"):
        cfg_path = Path.home() / ".config" / "bsubio" / "config.json"
        if cfg_path.exists():
            try:
                data = json.loads(cfg_path.read_text())
                api_key = data.get("api_key") or api_key
                base_url = data.get("base_url") or base_url
            except json.JSONDecodeError:
                pytest.skip(f"Failed to parse config file at {cfg_path}")

    if not api_key:
        pytest.skip("BSUB_API_KEY not set; live integration tests skipped.")

    cfg = Configuration(host=base_url) if base_url else Configuration()
    cfg.access_token = api_key
    return cfg


@pytest.fixture()
def live_api_client() -> ApiClient:
    cfg = _require_live_config()
    with ApiClient(cfg) as client:
        yield client


@pytest.fixture()
def live_apis(live_api_client):
    return {
        "jobs": JobsApi(live_api_client),
        "output": OutputApi(live_api_client),
        "system": SystemApi(live_api_client),
    }


def _choose_processing_type(system_api: SystemApi):
    available = system_api.get_types().types or []
    if not available:
        pytest.skip("No processing types returned from /types.")

    preferred = next((pt for pt in available if pt.type == "passthru"), None)
    return preferred or available[0]


def _sample_file_for_type(proc_type):
    mime_list = (proc_type.input.mime_in if proc_type.input else None) or []
    pdf_path = Path(__file__).resolve().parent / "test_pdf.pdf"

    for mime in mime_list:
        if mime.startswith("text/"):
            return "sample.txt", b"hello from bsub integration test\n"
        if mime == "application/json":
            return "sample.json", b'{"message": "hello"}'
        if mime == "application/pdf":
            return pdf_path.name, pdf_path.read_bytes()
        if mime == "application/octet-stream":
            return "sample.bin", b"\x00\x01\x02test"

    return "sample.txt", b"hello from bsub integration test\n"


def _wait_for_completion(jobs_api: JobsApi, job_id, timeout_seconds: int = 120):
    deadline = time.time() + timeout_seconds
    last_status = None
    while time.time() < deadline:
        job_resp = jobs_api.get_job(job_id)
        job = getattr(job_resp, "data", job_resp)
        last_status = job.status
        if last_status in {"finished", "failed"}:
            return job
        time.sleep(2)
    pytest.skip(f"Job {job_id} did not finish within {timeout_seconds}s (last status={last_status}); leaving job for inspection.")


def test_live_job_lifecycle(live_apis):
    jobs_api: JobsApi = live_apis["jobs"]
    output_api: OutputApi = live_apis["output"]
    system_api: SystemApi = live_apis["system"]

    proc_type = _choose_processing_type(system_api)
    filename, file_bytes = _sample_file_for_type(proc_type)

    job_id = None
    finished_successfully = False
    try:
        create_resp = jobs_api.create_job(CreateJobRequest(type=proc_type.type))
        job_id = create_resp.data.id
        upload_token = create_resp.data.upload_token

        upload_resp = jobs_api.upload_job_data(job_id, upload_token, (filename, file_bytes))
        assert upload_resp.success is True
        if upload_resp.data_size is not None:
            assert upload_resp.data_size == len(file_bytes)

        submit_resp = jobs_api.submit_job(job_id)
        assert submit_resp.success is True

        job = _wait_for_completion(jobs_api, job_id)
        if job.status == "failed":
            logs = output_api.get_job_logs(job_id)
            pytest.fail(f"Job failed; logs:\n{logs}")

        output = output_api.get_job_output(job_id)
        assert isinstance(output, (bytes, bytearray))
        assert len(output) > 0

        logs = output_api.get_job_logs(job_id)
        assert isinstance(logs, str)
        finished_successfully = True
    finally:
        if job_id is not None and finished_successfully:
            # Clean up only after success; on failure leave the job for inspection.
            try:
                jobs_api.delete_job(job_id)
            except Exception:
                pass


def test_get_job_raises_on_unknown_id(live_apis):
    jobs_api: JobsApi = live_apis["jobs"]
    missing_id = uuid4()

    with pytest.raises(ApiException) as excinfo:
        jobs_api.get_job(missing_id)

    assert excinfo.value.status == 404



# coding: utf-8

"""
    BSUB.IO API

    REST API for batch processing compute-intensive workloads.  Submit jobs, upload data, and retrieve results through a simple API. Perfect for PDF processing, video transcoding, audio transcription, and more.  ## Authentication  All endpoints require Bearer token authentication using your API key:  ``` Authorization: Bearer <your-api-key> ```  Get your API key from the [Dashboard](/).  ## Job Lifecycle  1. **Create** a job with `POST /v1/jobs` - Returns job ID and upload token 2. **Upload** data with `POST /v1/upload/{jobId}` - Uses upload token 3. **Submit** for processing with `POST /v1/jobs/{jobId}/submit` 4. **Monitor** status with `GET /v1/jobs/{jobId}` 5. **Retrieve** output with `GET /v1/jobs/{jobId}/output`  ## Job States  - `created` - Job created, awaiting data upload - `loaded` - Data uploaded successfully - `pending` - Waiting in queue for a worker - `claimed` - Worker claimed the job - `preparing` - Worker preparing to process - `processing` - Processing started - `finished` - Processing completed successfully - `failed` - Processing failed with error 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json

from bsubio.models.create_job_request import CreateJobRequest


def test_create_job_request_round_trips_to_json() -> None:
    request = CreateJobRequest(type="passthru")

    serialized = request.to_json()
    parsed = CreateJobRequest.from_json(serialized)

    assert parsed is not None
    assert parsed.type == "passthru"
    assert json.loads(serialized) == {"type": "passthru"}


def test_create_job_request_dict_excludes_none() -> None:
    request = CreateJobRequest(type="passthru")
    assert request.to_dict() == {"type": "passthru"}



# coding: utf-8

"""
    BSUB.IO API

    REST API for batch processing compute-intensive workloads.  Submit jobs, upload data, and retrieve results through a simple API. Perfect for PDF processing, video transcoding, audio transcription, and more.  ## Authentication  All endpoints require Bearer token authentication using your API key:  ``` Authorization: Bearer <your-api-key> ```  Get your API key from the [Dashboard](/).  ## Job Lifecycle  1. **Create** a job with `POST /v1/jobs` - Returns job ID and upload token 2. **Upload** data with `POST /v1/upload/{jobId}` - Uses upload token 3. **Submit** for processing with `POST /v1/jobs/{jobId}/submit` 4. **Monitor** status with `GET /v1/jobs/{jobId}` 5. **Retrieve** output with `GET /v1/jobs/{jobId}/output`  ## Job States  - `created` - Job created, awaiting data upload - `loaded` - Data uploaded successfully - `pending` - Waiting in queue for a worker - `claimed` - Worker claimed the job - `preparing` - Worker preparing to process - `processing` - Processing started - `finished` - Processing completed successfully - `failed` - Processing failed with error 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from bsubio.models.upload_job_data200_response import UploadJobData200Response

class TestUploadJobData200Response(unittest.TestCase):
    """UploadJobData200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UploadJobData200Response:
        """Test UploadJobData200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UploadJobData200Response`
        """
        model = UploadJobData200Response()
        if include_optional:
            return UploadJobData200Response(
                success = True,
                message = 'File uploaded successfully',
                data_size = 1048576
            )
        else:
            return UploadJobData200Response(
        )
        """

    def testUploadJobData200Response(self):
        """Test UploadJobData200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    BSUB.IO API

    REST API for batch processing compute-intensive workloads.  Submit jobs, upload data, and retrieve results through a simple API. Perfect for PDF processing, video transcoding, audio transcription, and more.  ## Authentication  All endpoints require Bearer token authentication using your API key:  ``` Authorization: Bearer <your-api-key> ```  Get your API key from the [Dashboard](/).  ## Job Lifecycle  1. **Create** a job with `POST /v1/jobs` - Returns job ID and upload token 2. **Upload** data with `POST /v1/upload/{jobId}` - Uses upload token 3. **Submit** for processing with `POST /v1/jobs/{jobId}/submit` 4. **Monitor** status with `GET /v1/jobs/{jobId}` 5. **Retrieve** output with `GET /v1/jobs/{jobId}/output`  ## Job States  - `created` - Job created, awaiting data upload - `loaded` - Data uploaded successfully - `pending` - Waiting in queue for a worker - `claimed` - Worker claimed the job - `preparing` - Worker preparing to process - `processing` - Processing started - `finished` - Processing completed successfully - `failed` - Processing failed with error 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "JobsApi",
    "OutputApi",
    "SystemApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "CancelJob200Response",
    "CreateJob201Response",
    "CreateJobRequest",
    "Error",
    "GetTypes200Response",
    "GetVersion200Response",
    "Job",
    "ListJobs200Response",
    "ListJobs200ResponseData",
    "ProcessingType",
    "ProcessingTypeExample",
    "ProcessingTypeInput",
    "ProcessingTypeOutput",
    "SubmitJob200Response",
    "UploadJobData200Response",
]

# import apis into sdk package
from bsubio.api.jobs_api import JobsApi as JobsApi
from bsubio.api.output_api import OutputApi as OutputApi
from bsubio.api.system_api import SystemApi as SystemApi

# import ApiClient
from bsubio.api_response import ApiResponse as ApiResponse
from bsubio.api_client import ApiClient as ApiClient
from bsubio.configuration import Configuration as Configuration
from bsubio.exceptions import OpenApiException as OpenApiException
from bsubio.exceptions import ApiTypeError as ApiTypeError
from bsubio.exceptions import ApiValueError as ApiValueError
from bsubio.exceptions import ApiKeyError as ApiKeyError
from bsubio.exceptions import ApiAttributeError as ApiAttributeError
from bsubio.exceptions import ApiException as ApiException

# import models into sdk package
from bsubio.models.cancel_job200_response import CancelJob200Response as CancelJob200Response
from bsubio.models.create_job201_response import CreateJob201Response as CreateJob201Response
from bsubio.models.create_job_request import CreateJobRequest as CreateJobRequest
from bsubio.models.error import Error as Error
from bsubio.models.get_types200_response import GetTypes200Response as GetTypes200Response
from bsubio.models.get_version200_response import GetVersion200Response as GetVersion200Response
from bsubio.models.job import Job as Job
from bsubio.models.list_jobs200_response import ListJobs200Response as ListJobs200Response
from bsubio.models.list_jobs200_response_data import ListJobs200ResponseData as ListJobs200ResponseData
from bsubio.models.processing_type import ProcessingType as ProcessingType
from bsubio.models.processing_type_example import ProcessingTypeExample as ProcessingTypeExample
from bsubio.models.processing_type_input import ProcessingTypeInput as ProcessingTypeInput
from bsubio.models.processing_type_output import ProcessingTypeOutput as ProcessingTypeOutput
from bsubio.models.submit_job200_response import SubmitJob200Response as SubmitJob200Response
from bsubio.models.upload_job_data200_response import UploadJobData200Response as UploadJobData200Response




# coding: utf-8

"""
    BSUB.IO API

    REST API for batch processing compute-intensive workloads.  Submit jobs, upload data, and retrieve results through a simple API. Perfect for PDF processing, video transcoding, audio transcription, and more.  ## Authentication  All endpoints require Bearer token authentication using your API key:  ``` Authorization: Bearer <your-api-key> ```  Get your API key from the [Dashboard](/).  ## Job Lifecycle  1. **Create** a job with `POST /v1/jobs` - Returns job ID and upload token 2. **Upload** data with `POST /v1/upload/{jobId}` - Uses upload token 3. **Submit** for processing with `POST /v1/jobs/{jobId}/submit` 4. **Monitor** status with `GET /v1/jobs/{jobId}` 5. **Retrieve** output with `GET /v1/jobs/{jobId}/output`  ## Job States  - `created` - Job created, awaiting data upload - `loaded` - Data uploaded successfully - `pending` - Waiting in queue for a worker - `claimed` - Worker claimed the job - `preparing` - Worker preparing to process - `processing` - Processing started - `finished` - Processing completed successfully - `failed` - Processing failed with error 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501
from uuid import UUID
from typing import Any, Dict, List, Optional, Tuple, Union

from pydantic import Field, StrictBytes, StrictFloat, StrictInt, StrictStr, validate_call
from typing_extensions import Annotated
from bsubio.models.cancel_job200_response import CancelJob200Response
from bsubio.models.create_job201_response import CreateJob201Response
from bsubio.models.create_job_request import CreateJobRequest
from bsubio.models.list_jobs200_response import ListJobs200Response
from bsubio.models.submit_job200_response import SubmitJob200Response
from bsubio.models.upload_job_data200_response import UploadJobData200Response

from bsubio.api_client import ApiClient, RequestSerialized
from bsubio.api_response import ApiResponse
from bsubio.rest import RESTResponseType


class JobsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def cancel_job(
        self,
        job_id: Annotated[UUID, Field(description="Unique job identifier (UUID)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CancelJob200Response:
        """Cancel a job

        Cancels a pending or in-progress job. Finished or failed jobs cannot be cancelled. 

        :param job_id: Unique job identifier (UUID) (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._cancel_job_serialize(
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CancelJob200Response",
            '400': "Error",
            '401': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def cancel_job_with_http_info(
        self,
        job_id: Annotated[UUID, Field(description="Unique job identifier (UUID)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CancelJob200Response]:
        """Cancel a job

        Cancels a pending or in-progress job. Finished or failed jobs cannot be cancelled. 

        :param job_id: Unique job identifier (UUID) (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._cancel_job_serialize(
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CancelJob200Response",
            '400': "Error",
            '401': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def cancel_job_without_preload_content(
        self,
        job_id: Annotated[UUID, Field(description="Unique job identifier (UUID)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Cancel a job

        Cancels a pending or in-progress job. Finished or failed jobs cannot be cancelled. 

        :param job_id: Unique job identifier (UUID) (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._cancel_job_serialize(
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CancelJob200Response",
            '400': "Error",
            '401': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _cancel_job_serialize(
        self,
        job_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if job_id is not None:
            _path_params['jobId'] = job_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v1/jobs/{jobId}/cancel',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def create_job(
        self,
        create_job_request: CreateJobRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CreateJob201Response:
        """Create a new job

        Creates a new job and returns a job ID and upload token. The upload token is required for uploading data to the job. 

        :param create_job_request: (required)
        :type create_job_request: CreateJobRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_job_serialize(
            create_job_request=create_job_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "CreateJob201Response",
            '400': "Error",
            '401': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_job_with_http_info(
        self,
        create_job_request: CreateJobRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CreateJob201Response]:
        """Create a new job

        Creates a new job and returns a job ID and upload token. The upload token is required for uploading data to the job. 

        :param create_job_request: (required)
        :type create_job_request: CreateJobRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_job_serialize(
            create_job_request=create_job_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "CreateJob201Response",
            '400': "Error",
            '401': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_job_without_preload_content(
        self,
        create_job_request: CreateJobRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create a new job

        Creates a new job and returns a job ID and upload token. The upload token is required for uploading data to the job. 

        :param create_job_request: (required)
        :type create_job_request: CreateJobRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_job_serialize(
            create_job_request=create_job_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "CreateJob201Response",
            '400': "Error",
            '401': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_job_serialize(
        self,
        create_job_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if create_job_request is not None:
            _body_params = create_job_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v1/jobs',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_job(
        self,
        job_id: Annotated[UUID, Field(description="Unique job identifier (UUID)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete a job

        Deletes a job and its associated data. Only finished or failed jobs can be deleted. 

        :param job_id: Unique job identifier (UUID) (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_job_serialize(
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '401': "Error",
            '404': "Error",
            '409': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_job_with_http_info(
        self,
        job_id: Annotated[UUID, Field(description="Unique job identifier (UUID)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete a job

        Deletes a job and its associated data. Only finished or failed jobs can be deleted. 

        :param job_id: Unique job identifier (UUID) (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_job_serialize(
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '401': "Error",
            '404': "Error",
            '409': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_job_without_preload_content(
        self,
        job_id: Annotated[UUID, Field(description="Unique job identifier (UUID)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete a job

        Deletes a job and its associated data. Only finished or failed jobs can be deleted. 

        :param job_id: Unique job identifier (UUID) (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_job_serialize(
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '401': "Error",
            '404': "Error",
            '409': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_job_serialize(
        self,
        job_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if job_id is not None:
            _path_params['jobId'] = job_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/v1/jobs/{jobId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_job(
        self,
        job_id: Annotated[UUID, Field(description="Unique job identifier (UUID)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CreateJob201Response:
        """Get job details

        Returns detailed information about a specific job

        :param job_id: Unique job identifier (UUID) (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_job_serialize(
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CreateJob201Response",
            '401': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_job_with_http_info(
        self,
        job_id: Annotated[UUID, Field(description="Unique job identifier (UUID)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CreateJob201Response]:
        """Get job details

        Returns detailed information about a specific job

        :param job_id: Unique job identifier (UUID) (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_job_serialize(
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CreateJob201Response",
            '401': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_job_without_preload_content(
        self,
        job_id: Annotated[UUID, Field(description="Unique job identifier (UUID)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get job details

        Returns detailed information about a specific job

        :param job_id: Unique job identifier (UUID) (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_job_serialize(
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CreateJob201Response",
            '401': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_job_serialize(
        self,
        job_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if job_id is not None:
            _path_params['jobId'] = job_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/jobs/{jobId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def list_jobs(
        self,
        status: Annotated[Optional[StrictStr], Field(description="Filter by job status")] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="Maximum number of jobs to return")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ListJobs200Response:
        """List jobs

        Returns a paginated list of jobs for the authenticated user. Results can be filtered by status and limited. 

        :param status: Filter by job status
        :type status: str
        :param limit: Maximum number of jobs to return
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_jobs_serialize(
            status=status,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListJobs200Response",
            '401': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_jobs_with_http_info(
        self,
        status: Annotated[Optional[StrictStr], Field(description="Filter by job status")] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="Maximum number of jobs to return")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ListJobs200Response]:
        """List jobs

        Returns a paginated list of jobs for the authenticated user. Results can be filtered by status and limited. 

        :param status: Filter by job status
        :type status: str
        :param limit: Maximum number of jobs to return
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_jobs_serialize(
            status=status,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListJobs200Response",
            '401': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_jobs_without_preload_content(
        self,
        status: Annotated[Optional[StrictStr], Field(description="Filter by job status")] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="Maximum number of jobs to return")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List jobs

        Returns a paginated list of jobs for the authenticated user. Results can be filtered by status and limited. 

        :param status: Filter by job status
        :type status: str
        :param limit: Maximum number of jobs to return
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_jobs_serialize(
            status=status,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListJobs200Response",
            '401': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_jobs_serialize(
        self,
        status,
        limit,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if status is not None:
            
            _query_params.append(('status', status))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/jobs',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def submit_job(
        self,
        job_id: Annotated[UUID, Field(description="Unique job identifier (UUID)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SubmitJob200Response:
        """Submit job for processing

        Submits a job for processing after data has been uploaded. The job moves from 'loaded' to 'pending' state and enters the queue. 

        :param job_id: Unique job identifier (UUID) (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._submit_job_serialize(
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SubmitJob200Response",
            '400': "Error",
            '401': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def submit_job_with_http_info(
        self,
        job_id: Annotated[UUID, Field(description="Unique job identifier (UUID)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SubmitJob200Response]:
        """Submit job for processing

        Submits a job for processing after data has been uploaded. The job moves from 'loaded' to 'pending' state and enters the queue. 

        :param job_id: Unique job identifier (UUID) (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._submit_job_serialize(
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SubmitJob200Response",
            '400': "Error",
            '401': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def submit_job_without_preload_content(
        self,
        job_id: Annotated[UUID, Field(description="Unique job identifier (UUID)")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Submit job for processing

        Submits a job for processing after data has been uploaded. The job moves from 'loaded' to 'pending' state and enters the queue. 

        :param job_id: Unique job identifier (UUID) (required)
        :type job_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._submit_job_serialize(
            job_id=job_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SubmitJob200Response",
            '400': "Error",
            '401': "Error",
            '404': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _submit_job_serialize(
        self,
        job_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if job_id is not None:
            _path_params['jobId'] = job_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v1/jobs/{jobId}/submit',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def upload_job_data(
        self,
        job_id: Annotated[UUID, Field(description="Job ID")],
        token: Annotated[StrictStr, Field(description="Upload token from job creation")],
        file: Annotated[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]], Field(description="File to process")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UploadJobData200Response:
        """Upload data to a job

        Uploads the input file for processing. Requires the upload token obtained when creating the job. 

        :param job_id: Job ID (required)
        :type job_id: str
        :param token: Upload token from job creation (required)
        :type token: str
        :param file: File to process (required)
        :type file: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._upload_job_data_serialize(
            job_id=job_id,
            token=token,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UploadJobData200Response",
            '400': "Error",
            '401': "Error",
            '404': "Error",
            '413': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def upload_job_data_with_http_info(
        self,
        job_id: Annotated[UUID, Field(description="Job ID")],
        token: Annotated[StrictStr, Field(description="Upload token from job creation")],
        file: Annotated[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]], Field(description="File to process")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UploadJobData200Response]:
        """Upload data to a job

        Uploads the input file for processing. Requires the upload token obtained when creating the job. 

        :param job_id: Job ID (required)
        :type job_id: str
        :param token: Upload token from job creation (required)
        :type token: str
        :param file: File to process (required)
        :type file: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._upload_job_data_serialize(
            job_id=job_id,
            token=token,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UploadJobData200Response",
            '400': "Error",
            '401': "Error",
            '404': "Error",
            '413': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def upload_job_data_without_preload_content(
        self,
        job_id: Annotated[UUID, Field(description="Job ID")],
        token: Annotated[StrictStr, Field(description="Upload token from job creation")],
        file: Annotated[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]], Field(description="File to process")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Upload data to a job

        Uploads the input file for processing. Requires the upload token obtained when creating the job. 

        :param job_id: Job ID (required)
        :type job_id: str
        :param token: Upload token from job creation (required)
        :type token: str
        :param file: File to process (required)
        :type file: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._upload_job_data_serialize(
            job_id=job_id,
            token=token,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UploadJobData200Response",
            '400': "Error",
            '401': "Error",
            '404': "Error",
            '413': "Error",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _upload_job_data_serialize(
        self,
        job_id,
        token,
        file,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if job_id is not None:
            _path_params['jobId'] = job_id
        # process the query parameters
        if token is not None:
            
            _query_params.append(('token', token))
            
        # process the header parameters
        # process the form parameters
        if file is not None:
            _files['file'] = file
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v1/upload/{jobId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )



# coding: utf-8

"""
    BSUB.IO API

    REST API for batch processing compute-intensive workloads.  Submit jobs, upload data, and retrieve results through a simple API. Perfect for PDF processing, video transcoding, audio transcription, and more.  ## Authentication  All endpoints require Bearer token authentication using your API key:  ``` Authorization: Bearer <your-api-key> ```  Get your API key from the [Dashboard](/).  ## Job Lifecycle  1. **Create** a job with `POST /v1/jobs` - Returns job ID and upload token 2. **Upload** data with `POST /v1/upload/{jobId}` - Uses upload token 3. **Submit** for processing with `POST /v1/jobs/{jobId}/submit` 4. **Monitor** status with `GET /v1/jobs/{jobId}` 5. **Retrieve** output with `GET /v1/jobs/{jobId}/output`  ## Job States  - `created` - Job created, awaiting data upload - `loaded` - Data uploaded successfully - `pending` - Waiting in queue for a worker - `claimed` - Worker claimed the job - `preparing` - Worker preparing to process - `processing` - Processing started - `finished` - Processing completed successfully - `failed` - Processing failed with error 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "bsubio"
VERSION = "1.0.0"
PYTHON_REQUIRES = ">= 3.9"
REQUIRES = [
    "urllib3 >= 2.1.0, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="BSUB.IO API",
    author="bsub.io",
    author_email="contact@bsub.io",
    url="https://www.bsub.io",
    keywords=["OpenAPI", "OpenAPI-Generator", "BSUB.IO API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT",
    long_description_content_type='text/markdown',
    long_description="""\
    REST API for batch processing compute-intensive workloads.  Submit jobs, upload data, and retrieve results through a simple API. Perfect for PDF processing, video transcoding, audio transcription, and more.  ## Authentication  All endpoints require Bearer token authentication using your API key:  &#x60;&#x60;&#x60; Authorization: Bearer &lt;your-api-key&gt; &#x60;&#x60;&#x60;  Get your API key from the [Dashboard](/).  ## Job Lifecycle  1. **Create** a job with &#x60;POST /v1/jobs&#x60; - Returns job ID and upload token 2. **Upload** data with &#x60;POST /v1/upload/{jobId}&#x60; - Uses upload token 3. **Submit** for processing with &#x60;POST /v1/jobs/{jobId}/submit&#x60; 4. **Monitor** status with &#x60;GET /v1/jobs/{jobId}&#x60; 5. **Retrieve** output with &#x60;GET /v1/jobs/{jobId}/output&#x60;  ## Job States  - &#x60;created&#x60; - Job created, awaiting data upload - &#x60;loaded&#x60; - Data uploaded successfully - &#x60;pending&#x60; - Waiting in queue for a worker - &#x60;claimed&#x60; - Worker claimed the job - &#x60;preparing&#x60; - Worker preparing to process - &#x60;processing&#x60; - Processing started - &#x60;finished&#x60; - Processing completed successfully - &#x60;failed&#x60; - Processing failed with error 
    """,  # noqa: E501
    package_data={"bsubio": ["py.typed"]},
)


# coding: utf-8

"""
    BSUB.IO API

    REST API for batch processing compute-intensive workloads.  Submit jobs, upload data, and retrieve results through a simple API. Perfect for PDF processing, video transcoding, audio transcription, and more.  ## Authentication  All endpoints require Bearer token authentication using your API key:  ``` Authorization: Bearer <your-api-key> ```  Get your API key from the [Dashboard](/).  ## Job Lifecycle  1. **Create** a job with `POST /v1/jobs` - Returns job ID and upload token 2. **Upload** data with `POST /v1/upload/{jobId}` - Uses upload token 3. **Submit** for processing with `POST /v1/jobs/{jobId}/submit` 4. **Monitor** status with `GET /v1/jobs/{jobId}` 5. **Retrieve** output with `GET /v1/jobs/{jobId}/output`  ## Job States  - `created` - Job created, awaiting data upload - `loaded` - Data uploaded successfully - `pending` - Waiting in queue for a worker - `claimed` - Worker claimed the job - `preparing` - Worker preparing to process - `processing` - Processing started - `finished` - Processing completed successfully - `failed` - Processing failed with error 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from uuid import UUID
from typing import Optional, Set
from typing_extensions import Self

class Job(BaseModel):
    """
    Job
    """ # noqa: E501
    id: Optional[UUID] = Field(default=None, description="Unique job identifier")
    status: Optional[StrictStr] = Field(default=None, description="Current job status")
    type: Optional[StrictStr] = Field(default=None, description="Processing type")
    user_id: Optional[StrictStr] = Field(default=None, description="User who created the job")
    upload_token: Optional[StrictStr] = Field(default=None, description="Token for uploading data (only present in `created` state)")
    data_size: Optional[StrictInt] = Field(default=None, description="Size of uploaded data in bytes")
    claimed_by: Optional[StrictStr] = Field(default=None, description="Worker ID that claimed the job")
    error_code: Optional[StrictStr] = Field(default=None, description="Error code if job failed")
    error_message: Optional[StrictStr] = Field(default=None, description="Error message if job failed")
    created_at: Optional[datetime] = Field(default=None, description="Job creation timestamp")
    updated_at: Optional[datetime] = Field(default=None, description="Last update timestamp")
    claimed_at: Optional[datetime] = Field(default=None, description="When job was claimed by worker")
    finished_at: Optional[datetime] = Field(default=None, description="When job finished (success or failure)")
    __properties: ClassVar[List[str]] = ["id", "status", "type", "user_id", "upload_token", "data_size", "claimed_by", "error_code", "error_message", "created_at", "updated_at", "claimed_at", "finished_at"]

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['created', 'loaded', 'pending', 'claimed', 'preparing', 'processing', 'finished', 'failed']):
            raise ValueError("must be one of enum values ('created', 'loaded', 'pending', 'claimed', 'preparing', 'processing', 'finished', 'failed')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Job from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if claimed_by (nullable) is None
        # and model_fields_set contains the field
        if self.claimed_by is None and "claimed_by" in self.model_fields_set:
            _dict['claimed_by'] = None

        # set to None if error_code (nullable) is None
        # and model_fields_set contains the field
        if self.error_code is None and "error_code" in self.model_fields_set:
            _dict['error_code'] = None

        # set to None if error_message (nullable) is None
        # and model_fields_set contains the field
        if self.error_message is None and "error_message" in self.model_fields_set:
            _dict['error_message'] = None

        # set to None if claimed_at (nullable) is None
        # and model_fields_set contains the field
        if self.claimed_at is None and "claimed_at" in self.model_fields_set:
            _dict['claimed_at'] = None

        # set to None if finished_at (nullable) is None
        # and model_fields_set contains the field
        if self.finished_at is None and "finished_at" in self.model_fields_set:
            _dict['finished_at'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Job from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "status": obj.get("status"),
            "type": obj.get("type"),
            "user_id": obj.get("user_id"),
            "upload_token": obj.get("upload_token"),
            "data_size": obj.get("data_size"),
            "claimed_by": obj.get("claimed_by"),
            "error_code": obj.get("error_code"),
            "error_message": obj.get("error_message"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "claimed_at": obj.get("claimed_at"),
            "finished_at": obj.get("finished_at")
        })
        return _obj





# coding: utf-8

# flake8: noqa
"""
    BSUB.IO API

    REST API for batch processing compute-intensive workloads.  Submit jobs, upload data, and retrieve results through a simple API. Perfect for PDF processing, video transcoding, audio transcription, and more.  ## Authentication  All endpoints require Bearer token authentication using your API key:  ``` Authorization: Bearer <your-api-key> ```  Get your API key from the [Dashboard](/).  ## Job Lifecycle  1. **Create** a job with `POST /v1/jobs` - Returns job ID and upload token 2. **Upload** data with `POST /v1/upload/{jobId}` - Uses upload token 3. **Submit** for processing with `POST /v1/jobs/{jobId}/submit` 4. **Monitor** status with `GET /v1/jobs/{jobId}` 5. **Retrieve** output with `GET /v1/jobs/{jobId}/output`  ## Job States  - `created` - Job created, awaiting data upload - `loaded` - Data uploaded successfully - `pending` - Waiting in queue for a worker - `claimed` - Worker claimed the job - `preparing` - Worker preparing to process - `processing` - Processing started - `finished` - Processing completed successfully - `failed` - Processing failed with error 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from bsubio.models.cancel_job200_response import CancelJob200Response
from bsubio.models.create_job201_response import CreateJob201Response
from bsubio.models.create_job_request import CreateJobRequest
from bsubio.models.error import Error
from bsubio.models.get_types200_response import GetTypes200Response
from bsubio.models.get_version200_response import GetVersion200Response
from bsubio.models.job import Job
from bsubio.models.list_jobs200_response import ListJobs200Response
from bsubio.models.list_jobs200_response_data import ListJobs200ResponseData
from bsubio.models.processing_type import ProcessingType
from bsubio.models.processing_type_example import ProcessingTypeExample
from bsubio.models.processing_type_input import ProcessingTypeInput
from bsubio.models.processing_type_output import ProcessingTypeOutput
from bsubio.models.submit_job200_response import SubmitJob200Response
from bsubio.models.upload_job_data200_response import UploadJobData200Response

